@@ -11,15 +11,20 @@ else if (file_exists(SM_PATH . 'src/validate.php'))
 include_once(SM_PATH . 'functions/page_header.php');
 
 sqgetGlobalVar('url', $url, SQ_GET);
+if (!isset($url)) sqgetGlobalVar('url', $url, SQ_POST);
 sqgetGlobalVar('passval', $passval, SQ_GET);
+if (!isset($passval)) sqgetGlobalVar('passval', $passval, SQ_POST);
 sqgetGlobalVar('folder', $folder, SQ_GET);
+if (!isset($folder)) sqgetGlobalVar('folder', $folder, SQ_POST);
 sqgetGlobalVar('title', $title, SQ_GET);
+if (!isset($title)) sqgetGlobalVar('title', $title, SQ_POST);
 
+$passval = urldecode($passval);
 
 if (!isset($url)) {
 	displayPageHeader($color, 'None');
 	echo '<br><br>';
-	echo '<form method="GET" action="bookmark_create.php">';
+	echo '<form method="POST" action="bookmark_create.php">';
 	echo '<input type="hidden" name="folder" value="' . $passval . '">';
 	echo 'URL:<br><input type="text" name="url" value="">';
 	echo '<br><br>';
@@ -30,6 +35,8 @@ if (!isset($url)) {
 	echo '</form>';
 	echo '</body></html>';
 } else {
+  $url = urldecode($url);
+
 	$bookmarksdata = $_SESSION["bookmarksdata"];
 
 	if ((substr(strtolower($url),0,7) != 'http://') && (substr(strtolower($url),0,6) != 'ftp://') && (substr(strtolower($url),0,8) != 'https://') && (substr(strtolower($url),0,9) != 'telnet://') && (substr(strtolower($url),0,7) != 'nntp://')) {
@@ -55,19 +62,21 @@ if (!isset($url)) {
 		} else {
 			$sk = fopen($prefix . $targeturl . "?" . $querystring, "r");
 		}
-		while(!feof($sk)){
-			$resp=fgets($sk,80);
-			$retstr.=$resp;
+		if ($sk != false) {
+  		while(!feof($sk)){
+  			$resp=fgets($sk,80);
+  			$retstr.=$resp;
+  		}
+  		fclose($sk);
+  		$sString = $retstr;
+  		$sString = str_replace('<title>','<TITLE>',$sString);
+  		$sString = str_replace('</title>','</TITLE>',$sString);
+  		$explode = explode("<TITLE>",$sString);
+  		$sString = $explode[1];
+  		$explode = explode("</TITLE>",$sString);
+  		$sString = $explode[0];
+  		$title = ereg_replace("(\r\n|\n|\r)", "", $sString);
 		}
-		fclose($sk);
-		$sString = $retstr;
-		$sString = str_replace('<title>','<TITLE>',$sString);
-		$sString = str_replace('</title>','</TITLE>',$sString);
-		$explode = explode("<TITLE>",$sString);
-		$sString = $explode[1];
-		$explode = explode("</TITLE>",$sString);
-		$sString = $explode[0];
-		$title = ereg_replace("(\r\n|\n|\r)", "", $sString);
 	}
 	if ($title == "") {
 		$title = $url;
@@ -79,6 +88,6 @@ if (!isset($url)) {
 	$bookmarksdata[$bookindex]["url"] = $url;
 
 	writebookmarksdata();
-	header('Location: bookmarks.php?passval=' . $folder );
+	header('Location: bookmarks.php?passval=' . urlencode($folder));
 }
 ?>
